pub enum Interpolation {
Nearest,
Smooth,
}Expand description
Interpolation when scaling images.
This is meant to be translated from the ImageRendering property. We don’t use
ImageRendering directly here, because this module is supposed to be lower-level
than the main part of librsvg. Here, we take Interpolation and translate it
to Cairo’s own values for pattern filtering.
This enum can be expanded to use more of Cairo’s filtering modes.
Variants